@@ -6,7 +6,7 @@ if [ "$1" == "i" ]; then
     export CSF_FPE=0
 
     export TCL_DIR="${THIRDPARTY_DIR}/lib64"
-    export TK_DIR=""
+    export TK_DIR="${THIRDPARTY_DIR}/lib64"
     export FREETYPE_DIR=""
     export FREEIMAGE_DIR=""
     export TBB_DIR=""
